@@ -6,6 +6,7 @@ from livestyled.models.cohort import Cohort
 from livestyled.models.competition import Competition
 from livestyled.models.device import Device
 from livestyled.models.device_consent import DeviceConsent
+from livestyled.models.device_form_data import DeviceFormData
 from livestyled.models.device_preference import DevicePreference
 from livestyled.models.device_push_consent import DevicePushConsent
 from livestyled.models.device_reality import DeviceReality
@@ -53,6 +54,7 @@ __all__ = [
     Competition,
     Device,
     DeviceConsent,
+    DeviceFormData,
     DevicePreference,
     DevicePushConsent,
     DeviceReality,
